@@ -108,11 +108,16 @@ def close_output_file(f: typing.TextIO) -> None:
   if f.name != '<stdout>':
     f.close()
 
-def print_yaml(x : typing.Any) -> str:
+ruamel_attrs: typing.Final[dict] = {'version': (1,1)}
+
+def get_yaml_string(x : typing.Any) -> str:
+  global ruamel_attrs
+  if isinstance(x, Box) or isinstance(x,BoxList):
+    return x.to_yaml(ruamel_attrs=ruamel_attrs)
   if isinstance(x,dict):
-    return Box(x).to_yaml()
+    return Box(x).to_yaml(ruamel_attrs=ruamel_attrs)
   elif isinstance(x,list):
-    return BoxList(x).to_yaml()
+    return BoxList(x).to_yaml(ruamel_attrs=ruamel_attrs)
   else:
     return str(x)
 
