@@ -99,11 +99,13 @@ def create(nodes: Box, groups: Box, defaults: Box, addressing: typing.Optional[B
 
   return inventory
 
+# Note to self: the dump function is used by the testing scripts. Do not remove
+#
 def dump(data: Box) -> None:
   print("Ansible inventory data")
   print("===============================")
   inventory = create(data.nodes,data.get('groups',{}),data.defaults)
-  print(inventory.to_yaml())
+  print(common.get_yaml_string(inventory))
 
 def write_yaml(data: Box, fname: str, header: str) -> None:
   dirname = os.path.dirname(fname)
@@ -112,10 +114,7 @@ def write_yaml(data: Box, fname: str, header: str) -> None:
 
   with open(fname,"w") as output:
     output.write(header)
-    if callable(getattr(data,"to_yaml",None)):
-      output.write(data.to_yaml())
-    else:                            # pragma: no cover -- this should never happen as we're using Box, but just in case...
-      output.write(yaml.dump(data))
+    output.write(common.get_yaml_string(data))
     output.close()
 
 min_inventory_data = [ 'id','ansible_host','ansible_port' ]
